#include "dact.h"
#include "config.h"

#if defined(USE_MODULES) && !defined(AS_MODULE)
#define comp_delta_algo DACT_FAILED_ALGO
#else
int comp_delta_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_delta_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
int comp_delta_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
#endif
